Zuul - A Project Gating System
==============================

Zuul is a program that drives continuous integration, delivery, and
deployment systems with a focus on project gating and interrelated
projects.

If you are looking for the Edge routing service named Zuul that is
related to Netflix, it can be found here:
https://github.com/Netflix/zuul

If you are looking for the Javascript testing tool named Zuul, it
can be found here:
https://github.com/defunctzombie/zuul


How To Use This Manual
----------------------

If you have access to a Zuul system operated by someone else, then you
may be interested in :ref:`about-zuul` and the following reference
sections: :ref:`project-configuration` and :ref:`job-content`.

If you would like to learn how to run Zuul, try the :ref:`quick-start`.

If you are or will be responsible for installing and operating a Zuul
System, the remainder of the sections will be useful.

.. toctree::
   :includehidden:
   :maxdepth: 1

   about
   tutorials/quick-start
   project-config
   job-content
   admin
   rest-api
   howtos/index
   developer/index
   governance
   vulnerabilities
   releasenotes
   glossary

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

